@@ -17,6 +17,15 @@ class AftSurvivalRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -33,6 +42,38 @@ class AftSurvivalRegPredictStreamOp(BaseModelStreamOp):
         return self._add_param('vectorCol', val)
 
 
+class AggLookupStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.AggLookupStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AggLookupStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setDelimiter(self, val):
+        return self._add_param('delimiter', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class AkSinkStreamOp(BaseSinkStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.sink.AkSinkStreamOp'
     OP_TYPE = 'SINK'
@@ -86,9 +127,21 @@ class AlsItemsPerUserRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -115,6 +168,15 @@ class AlsRateRecommStreamOp(BaseModelStreamOp):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -138,9 +200,21 @@ class AlsSimilarItemsRecommStreamOp(BaseModelStreamOp):
     def setRecommCol(self, val):
         return self._add_param('recommCol', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -164,9 +238,21 @@ class AlsSimilarUsersRecommStreamOp(BaseModelStreamOp):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -193,9 +279,21 @@ class AlsUsersPerItemRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -230,6 +328,9 @@ class BinarizerStreamOp(StreamOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -253,6 +354,15 @@ class BisectingKMeansPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -294,6 +404,15 @@ class BucketizerStreamOp(StreamOperator):
     def setLeftOpen(self, val):
         return self._add_param('leftOpen', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -317,6 +436,15 @@ class C45PredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -340,6 +468,15 @@ class CartPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -363,6 +500,15 @@ class CartRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -531,6 +677,32 @@ class ColumnsToVectorStreamOp(StreamOperator):
         return self._add_param('vectorSize', val)
 
 
+class CrossFeaturePredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.CrossFeaturePredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CrossFeaturePredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+
 class CsvSinkStreamOp(BaseSinkStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.sink.CsvSinkStreamOp'
     OP_TYPE = 'SINK'
@@ -777,6 +949,9 @@ class DCTStreamOp(StreamOperator):
     def setInverse(self, val):
         return self._add_param('inverse', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -797,6 +972,15 @@ class DecisionTreePredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -820,6 +1004,15 @@ class DecisionTreeRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -863,6 +1056,15 @@ class DocHashCountVectorizerPredictStreamOp(BaseModelStreamOp):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -915,6 +1117,15 @@ class EqualWidthDiscretizerPredictStreamOp(BaseModelStreamOp):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -996,6 +1207,9 @@ class FeatureHasherStreamOp(StreamOperator):
     def setNumFeatures(self, val):
         return self._add_param('numFeatures', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -1050,6 +1264,15 @@ class FmClassifierPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1082,9 +1305,21 @@ class FmItemsPerUserRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1105,6 +1340,15 @@ class FmRegressorPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1137,9 +1381,21 @@ class FmUsersPerItemRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1186,6 +1442,18 @@ class FtrlPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
@@ -1236,52 +1504,3 @@ class FtrlTrainStreamOp(BaseModelStreamOp):
     def setWithIntercept(self, val):
         return self._add_param('withIntercept', val)
 
-
-class GBRankPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.GBRankPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(GBRankPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class GbdtPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.GbdtPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(GbdtPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
