@@ -4,6 +4,366 @@
 from ..base import StreamOperator, BaseSinkStreamOp, BaseModelStreamOp
 
 
+class OneHotPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.OneHotPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(OneHotPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setDropLast(self, val):
+        return self._add_param('dropLast', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class OverCountWindowStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.OverCountWindowStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(OverCountWindowStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setTimeCol(self, val):
+        return self._add_param('timeCol', val)
+
+    def setLatency(self, val):
+        return self._add_param('latency', val)
+
+    def setPartitionCols(self, val):
+        return self._add_param('partitionCols', val)
+
+    def setPrecedingRows(self, val):
+        return self._add_param('precedingRows', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWatermarkType(self, val):
+        return self._add_param('watermarkType', val)
+
+
+class OverTimeWindowStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.OverTimeWindowStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(OverTimeWindowStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setTimeCol(self, val):
+        return self._add_param('timeCol', val)
+
+    def setLatency(self, val):
+        return self._add_param('latency', val)
+
+    def setPartitionCols(self, val):
+        return self._add_param('partitionCols', val)
+
+    def setPrecedingTime(self, val):
+        return self._add_param('precedingTime', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWatermarkType(self, val):
+        return self._add_param('watermarkType', val)
+
+
+class PcaPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.PcaPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PcaPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
+class PipelinePredictStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.PipelineModel$PipelinePredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PipelinePredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+
+class PrintStreamOp(BaseSinkStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.utils.PrintStreamOp'
+    OP_TYPE = 'SINK'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PrintStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setMaxLimit(self, val):
+        return self._add_param('maxLimit', val)
+
+    def setRefreshInterval(self, val):
+        return self._add_param('refreshInterval', val)
+
+
+class PyBinaryScalarFunctionStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryScalarFunctionStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PyBinaryScalarFunctionStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClassObject(self, val):
+        return self._add_param('classObject', val)
+
+    def setClassObjectType(self, val):
+        return self._add_param('classObjectType', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setResultType(self, val):
+        return self._add_param('resultType', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class PyBinaryTableFunctionStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.executor.udf.python.PyBinaryTableFunctionStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(PyBinaryTableFunctionStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClassObject(self, val):
+        return self._add_param('classObject', val)
+
+    def setClassObjectType(self, val):
+        return self._add_param('classObjectType', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setResultTypes(self, val):
+        return self._add_param('resultTypes', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class QuantileDiscretizerPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.QuantileDiscretizerPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(QuantileDiscretizerPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setDropLast(self, val):
+        return self._add_param('dropLast', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class RandomForestPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.RandomForestPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class RandomForestRegPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.RandomForestRegPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestRegPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class RandomTableSourceStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.source.RandomTableSourceStreamOp'
+    OP_TYPE = 'SOURCE'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomTableSourceStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setMaxRows(self, val):
+        return self._add_param('maxRows', val)
+
+    def setNumCols(self, val):
+        return self._add_param('numCols', val)
+
+    def setIdCol(self, val):
+        return self._add_param('idCol', val)
+
+    def setOutputColConfs(self, val):
+        return self._add_param('outputColConfs', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setTimePerSample(self, val):
+        return self._add_param('timePerSample', val)
+
+    def setTimeZones(self, val):
+        return self._add_param('timeZones', val)
+
+
 class RandomVectorSourceStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.source.RandomVectorSourceStreamOp'
     OP_TYPE = 'SOURCE'
@@ -52,6 +412,9 @@ class RegexTokenizerStreamOp(StreamOperator):
     def setMinTokenLength(self, val):
         return self._add_param('minTokenLength', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -78,6 +441,15 @@ class RidgeRegPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -118,6 +490,9 @@ class SegmentStreamOp(StreamOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -142,6 +517,35 @@ class SelectStreamOp(StreamOperator):
         return self._add_param('clause', val)
 
 
+class SessionTimeWindowStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.SessionTimeWindowStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SessionTimeWindowStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setSessionGapTime(self, val):
+        return self._add_param('sessionGapTime', val)
+
+    def setTimeCol(self, val):
+        return self._add_param('timeCol', val)
+
+    def setLatency(self, val):
+        return self._add_param('latency', val)
+
+    def setPartitionCols(self, val):
+        return self._add_param('partitionCols', val)
+
+    def setWatermarkType(self, val):
+        return self._add_param('watermarkType', val)
+
+
 class SideOutputStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.utils.SideOutputStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -186,6 +590,15 @@ class SoftmaxPredictStreamOp(BaseModelStreamOp):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -243,6 +656,15 @@ class StandardScalerPredictStreamOp(BaseModelStreamOp):
         super(StandardScalerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -266,6 +688,9 @@ class StopWordsRemoverStreamOp(StreamOperator):
     def setCaseSensitive(self, val):
         return self._add_param('caseSensitive', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -341,6 +766,15 @@ class StringIndexerPredictStreamOp(BaseModelStreamOp):
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -379,6 +813,9 @@ class StringSimilarityPairwiseStreamOp(StreamOperator):
     def setNumHashTables(self, val):
         return self._add_param('numHashTables', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -389,6 +826,44 @@ class StringSimilarityPairwiseStreamOp(StreamOperator):
         return self._add_param('windowSize', val)
 
 
+class SwingRecommStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.recommendation.SwingRecommStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SwingRecommStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setItemCol(self, val):
+        return self._add_param('itemCol', val)
+
+    def setRecommCol(self, val):
+        return self._add_param('recommCol', val)
+
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
+    def setK(self, val):
+        return self._add_param('k', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class TextSimilarityPairwiseStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.similarity.TextSimilarityPairwiseStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -417,6 +892,9 @@ class TextSimilarityPairwiseStreamOp(StreamOperator):
     def setNumHashTables(self, val):
         return self._add_param('numHashTables', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -480,6 +958,9 @@ class TokenizerStreamOp(StreamOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -487,6 +968,35 @@ class TokenizerStreamOp(StreamOperator):
         return self._add_param('reservedCols', val)
 
 
+class TreeModelEncoderStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.TreeModelEncoderStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TreeModelEncoderStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class TsvSinkStreamOp(BaseSinkStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.sink.TsvSinkStreamOp'
     OP_TYPE = 'SINK'
@@ -530,6 +1040,35 @@ class TsvSourceStreamOp(StreamOperator):
         return self._add_param('skipBlankLine', val)
 
 
+class TumbleTimeWindowStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.TumbleTimeWindowStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TumbleTimeWindowStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setTimeCol(self, val):
+        return self._add_param('timeCol', val)
+
+    def setWindowTime(self, val):
+        return self._add_param('windowTime', val)
+
+    def setLatency(self, val):
+        return self._add_param('latency', val)
+
+    def setPartitionCols(self, val):
+        return self._add_param('partitionCols', val)
+
+    def setWatermarkType(self, val):
+        return self._add_param('watermarkType', val)
+
+
 class UnionAllStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.sql.UnionAllStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -560,9 +1099,21 @@ class UserCfItemsPerUserRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -589,6 +1140,15 @@ class UserCfRateRecommStreamOp(BaseModelStreamOp):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -612,9 +1172,21 @@ class UserCfSimilarUsersRecommStreamOp(BaseModelStreamOp):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -641,9 +1213,21 @@ class UserCfUsersPerItemRecommStreamOp(BaseModelStreamOp):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -670,6 +1254,9 @@ class VectorAssemblerStreamOp(StreamOperator):
     def setHandleInvalidMethod(self, val):
         return self._add_param('handleInvalidMethod', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -690,6 +1277,9 @@ class VectorElementwiseProductStreamOp(StreamOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -707,6 +1297,15 @@ class VectorImputerPredictStreamOp(BaseModelStreamOp):
         super(VectorImputerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -730,6 +1329,9 @@ class VectorInteractionStreamOp(StreamOperator):
     def setSelectedCols(self, val):
         return self._add_param('selectedCols', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -744,6 +1346,15 @@ class VectorMaxAbsScalerPredictStreamOp(BaseModelStreamOp):
         super(VectorMaxAbsScalerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -761,117 +1372,14 @@ class VectorMinMaxScalerPredictStreamOp(BaseModelStreamOp):
         super(VectorMinMaxScalerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
 
-
-class VectorNormalizeStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorNormalizeStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNormalizeStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setP(self, val):
-        return self._add_param('p', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorPolynomialExpandStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorPolynomialExpandStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorPolynomialExpandStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setDegree(self, val):
-        return self._add_param('degree', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorSizeHintStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorSizeHintStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorSizeHintStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setSize(self, val):
-        return self._add_param('size', val)
-
-    def setHandleInvalidMethod(self, val):
-        return self._add_param('handleInvalidMethod', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorSliceStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorSliceStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorSliceStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setIndices(self, val):
-        return self._add_param('indices', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorStandardScalerPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorStandardScalerPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorStandardScalerPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
 
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
@@ -879,208 +1387,3 @@ class VectorStandardScalerPredictStreamOp(BaseModelStreamOp):
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-
-class VectorToColumnsStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.VectorToColumnsStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToColumnsStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorToCsvStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.VectorToCsvStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToCsvStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorToJsonStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.VectorToJsonStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToJsonStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setJsonCol(self, val):
-        return self._add_param('jsonCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorToKvStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.VectorToKvStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToKvStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorToTripleStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.VectorToTripleStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToTripleStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setTripleColumnValueSchemaStr(self, val):
-        return self._add_param('tripleColumnValueSchemaStr', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class WhereStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sql.WhereStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(WhereStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setClause(self, val):
-        return self._add_param('clause', val)
-
-
-class WindowGroupByStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sql.WindowGroupByStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(WindowGroupByStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectClause(self, val):
-        return self._add_param('selectClause', val)
-
-    def setSessionGap(self, val):
-        return self._add_param('sessionGap', val)
-
-    def setSlidingLength(self, val):
-        return self._add_param('slidingLength', val)
-
-    def setWindowLength(self, val):
-        return self._add_param('windowLength', val)
-
-    def setGroupByClause(self, val):
-        return self._add_param('groupByClause', val)
-
-    def setIntervalUnit(self, val):
-        return self._add_param('intervalUnit', val)
-
-    def setWindowType(self, val):
-        return self._add_param('windowType', val)
-
-
-class Word2VecPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.Word2VecPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Word2VecPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setPredMethod(self, val):
-        return self._add_param('predMethod', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setWordDelimiter(self, val):
-        return self._add_param('wordDelimiter', val)
-
